mark_select_tie: Marking ties based on measures

mark_select_tieR Documentation

Marking ties based on measures

Description

These functions return logical vectors the length of the ties in a network:

  • tie_is_random() marks one or more ties at random.

  • tie_is_max() and tie_is_min() are more useful for converting the results from some tie measure into a mark-class object. They can be particularly useful for highlighting which tie or ties are key because they minimise or, more often, maximise some measure.

Usage

tie_is_random(.data, select = 1)

tie_is_max(tie_measure)

tie_is_min(tie_measure)

Arguments

.data

A network object of class mnet, igraph, tbl_graph, network, or similar. For more information on the standard coercion possible, see manynet::as_tidygraph().

select

Number of elements to select (as TRUE).

tie_measure

An object created by a tie_ measure.

Value

A tie_mark logical vector the length of the ties in the network, giving either TRUE or FALSE for each tie depending on whether the condition is matched.

See Also

Other marks: mark_core, mark_degree, mark_diff, mark_dyads, mark_nodes, mark_select_node, mark_ties, mark_triangles

Other tie: mark_dyads, mark_ties, mark_triangles, measure_broker_tie, measure_centralities_between, measure_centralities_close, measure_centralities_degree, measure_centralities_eigen

Other selection: mark_select_node

Examples

tie_is_max(tie_by_betweenness(ison_brandes))
tie_is_min(tie_by_betweenness(ison_brandes))

netrics documentation built on July 24, 2026, 5:07 p.m.