measure_centralisation_degree: Measuring networks degree-like centralisation

measure_centralisation_degreeR Documentation

Measuring networks degree-like centralisation

Description

  • net_by_degree() measures a network's degree centralization as a single score; there are several related shortcut functions:

    • net_by_indegree() returns the direction = 'in' results.

    • net_by_outdegree() returns the direction = 'out' results.

  • mode_by_degree() measures degree centralization separately for each mode of a two-mode network, returning one score per mode (following Borgatti and Everett, 1997); it has the same shortcuts:

    • mode_by_indegree() returns the direction = 'in' results.

    • mode_by_outdegree() returns the direction = 'out' results.

All measures attempt to use as much information as they are offered, including whether the networks are directed, weighted, or multimodal. If this would produce unintended results, first transform the salient properties using e.g. to_undirected() functions. All centrality and centralization measures return normalized measures by default, including for two-mode networks.

For two-mode networks, the two modes have different theoretical maxima, so net_by_degree() reports a single network-level score by applying Freeman's general centralization index over the mode-normalized node degrees, whereas mode_by_degree() reports the per-mode centralization scores directly. For the per-mode scores, "all" uses as numerator the sum of differences between the maximum centrality score for the mode against all other centrality scores in the network, whereas "in" uses as numerator the sum of differences between the maximum centrality score for the mode against only the centrality scores of the other nodes in that mode.

Usage

net_by_degree(.data, normalized = TRUE, direction = c("all", "out", "in"))

mode_by_degree(.data, normalized = TRUE, direction = c("all", "out", "in"))

net_by_outdegree(.data, normalized = TRUE)

net_by_indegree(.data, normalized = TRUE)

mode_by_outdegree(.data, normalized = TRUE)

mode_by_indegree(.data, normalized = TRUE)

Arguments

.data

A network object of class mnet, igraph, tbl_graph, network, or similar. For more information on the standard coercion possible, see manynet::as_tidygraph().

normalized

Logical scalar, whether scores are normalized. Different denominators may be used depending on the measure, whether the object is one-mode or two-mode, and other arguments. By default TRUE.

direction

Character string, “out” bases the measure on outgoing ties, “in” on incoming ties, and "all" on either/the sum of the two. By default "all".

Value

⁠net_by_*()⁠ functions return a network_measure scalar; ⁠mode_by_*()⁠ functions return a mode_measure numeric vector of length two, giving one centralization score per mode.

References

Borgatti, Stephen P., and Martin G. Everett. 1997. "Network analysis of 2-mode data." Social Networks 19(3): 243-269. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/S0378-8733(96)00301-2")}

See Also

Other degree: mark_degree, measure_central_degree, measure_centralities_degree

Other centrality: measure_central_between, measure_central_close, measure_central_degree, measure_central_eigen, measure_centralisation_between, measure_centralisation_close, measure_centralisation_eigen, measure_centralities_between, measure_centralities_close, measure_centralities_degree, measure_centralities_eigen

Examples

net_by_degree(ison_southern_women, direction = "in")
mode_by_degree(ison_southern_women, direction = "in")

netrics documentation built on July 24, 2026, 5:07 p.m.