These functions include ways to take a census of the brokerage positions of nodes in a network:

  • node_x_brokerage() returns the Gould-Fernandez brokerage roles played by nodes in a network.

  • net_x_brokerage() returns the Gould-Fernandez brokerage roles in a network.

  • node_brokering_activity() measures nodes' brokerage activity.

  • node_brokering_exclusivity() measures nodes' brokerage exclusivity.

node_x_brokerage(.data, membership, standardized = FALSE)

net_x_brokerage(.data, membership, standardized = FALSE)

Arguments

.data

A network object of class mnet, igraph, tbl_graph, network, or similar. For more information on the standard coercion possible, see manynet::as_tidygraph().

membership

A vector of partition membership as integers.

standardized

Whether the score should be standardized into a z-score indicating how many standard deviations above or below the average the score lies.

References

On brokerage motifs

Gould, Roger V., and Roberto M. Fernandez. 1989. “Structures of Mediation: A Formal Approach to Brokerage in Transaction Networks.” Sociological Methodology, 19: 89-126. doi:10.2307/270949

Jasny, Lorien, and Mark Lubell. 2015. “Two-Mode Brokerage in Policy Networks.” Social Networks 41:36–47. doi:10.1016/j.socnet.2014.11.005

Examples

# node_x_brokerage(ison_networkers, "Discipline")
# net_x_brokerage(ison_networkers, "Discipline")