| mark_degree | R Documentation |
These functions return logical vectors the length of the nodes in a network identifying which hold certain properties or positions in the network.
node_is_isolate() marks nodes that are isolates,
with neither incoming nor outgoing ties.
node_is_pendant() marks nodes that are pendants,
with exactly one incoming or outgoing tie.
node_is_universal() identifies whether nodes are adjacent to all other
nodes in the network.
node_is_isolate(.data)
node_is_pendant(.data)
node_is_universal(.data)
.data |
A network object of class |
A node_mark logical vector the length of the nodes in the network,
giving either TRUE or FALSE for each node depending on
whether the condition is matched.
A universal node is adjacent to all other nodes in the network. It is also sometimes called the dominating vertex because it represents a one-element dominating set. A network with a universal node is called a cone, and its universal node is called the apex of the cone. A classic example of a cone is a star graph, but friendship, wheel, and threshold graphs are also cones.
Other degree:
measure_central_degree,
measure_centralisation_degree,
measure_centralities_degree
Other marks:
mark_core,
mark_diff,
mark_dyads,
mark_nodes,
mark_select_node,
mark_select_tie,
mark_ties,
mark_triangles
Other nodal:
mark_core,
mark_diff,
mark_nodes,
mark_select_node,
measure_assort_node,
measure_broker_node,
measure_brokerage,
measure_central_between,
measure_central_close,
measure_central_degree,
measure_central_eigen,
measure_closure_node,
measure_core,
measure_diffusion_node,
measure_diverse_node,
member_brokerage,
member_cliques,
member_community,
member_community_hier,
member_community_non,
member_components,
member_core,
member_diffusion,
member_equivalence,
motif_brokerage_node,
motif_exposure,
motif_node,
motif_path
node_is_isolate(ison_brandes)
node_is_universal(create_star(11))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.