These functions return logical vectors the length of the nodes in a network identifying which hold certain properties or positions in the network.
node_is_isolate() marks nodes that are isolates,
with neither incoming nor outgoing ties.
node_is_pendant() marks nodes that are pendants,
with exactly one incoming or outgoing tie.
node_is_universal() identifies whether nodes are adjacent to all other
nodes in the network.
node_is_isolate(.data)
node_is_pendant(.data)
node_is_universal(.data)A network object of class mnet, igraph, tbl_graph, network, or similar.
For more information on the standard coercion possible,
see manynet::as_tidygraph().
A universal node is adjacent to all other nodes in the network. It is also sometimes called the dominating vertex because it represents a one-element dominating set. A network with a universal node is called a cone, and its universal node is called the apex of the cone. A classic example of a cone is a star graph, but friendship, wheel, and threshold graphs are also cones.
Other marks:
mark_diff,
mark_nodes,
mark_select,
mark_tie_select,
mark_ties,
mark_triangles
Other degree:
measure_central_degree
node_is_isolate(ison_brandes)
#> N01 N02 N03 N04 N05 N06 N07 N08 N09 N10 N11
#> 1 FALSE FALSE FALSE FALSE FALSE FALSE FALSE FALSE FALSE FALSE FALSE
node_is_universal(create_star(11))
#> V1 V2 V3 V4 V5 V6 V7 V8 V9 V10 V11
#> 1 TRUE FALSE FALSE FALSE FALSE FALSE FALSE FALSE FALSE FALSE FALSE