mark_dyads: Marking ties based on dyadic properties

mark_dyadsR Documentation

Marking ties based on dyadic properties

Description

These functions return logical vectors the length of the ties in a network identifying which are embedded within particular dyads.

  • tie_is_multiple() marks ties that are multiples.

  • tie_is_reciprocated() marks ties that are mutual/reciprocated.

They are most useful in highlighting parts of the network where relationships are denser.

Usage

tie_is_multiple(.data)

tie_is_reciprocated(.data)

Arguments

.data

A network object of class mnet, igraph, tbl_graph, network, or similar. For more information on the standard coercion possible, see manynet::as_tidygraph().

Value

A tie_mark logical vector the length of the ties in the network, giving either TRUE or FALSE for each tie depending on whether the condition is matched.

See Also

Other marks: mark_core, mark_degree, mark_diff, mark_nodes, mark_select_node, mark_select_tie, mark_ties, mark_triangles

Other tie: mark_select_tie, mark_ties, mark_triangles, measure_broker_tie, measure_centralities_between, measure_centralities_close, measure_centralities_degree, measure_centralities_eigen

Examples

tie_is_multiple(fict_marvel)
tie_is_reciprocated(ison_algebra)

netrics documentation built on July 24, 2026, 5:07 p.m.