These functions return logical vectors the length of the ties in a network identifying which are embedded within particular dyads.

  • tie_is_multiple() marks ties that are multiples.

  • tie_is_reciprocated() marks ties that are mutual/reciprocated.

They are most useful in highlighting parts of the network where relationships are denser.

tie_is_multiple(.data)

tie_is_reciprocated(.data)

Arguments

.data

A network object of class mnet, igraph, tbl_graph, network, or similar. For more information on the standard coercion possible, see manynet::as_tidygraph().

Value

A tie_mark logical vector the length of the ties in the network, giving either TRUE or FALSE for each tie depending on whether the condition is matched.

Examples

tie_is_multiple(fict_marvel)
#>   `Abomination-Abomination` `Abomination-Beast` `Abomination-Colossus`
#> 1 FALSE                     FALSE               FALSE                 
#> # ... and 1238 more values from this nodeset. Use `print_all(...)` to print all values.
tie_is_reciprocated(ison_algebra)
#>   `1->5` `1->5` `1->8` `1->9` `1->9` `1->10` `1->10` `1->11` `1->12` `1->12`
#> 1 TRUE   TRUE   FALSE  TRUE   TRUE   TRUE    TRUE    TRUE    TRUE    TRUE   
#> # ... and 269 more values from this nodeset. Use `print_all(...)` to print all values.