| mark_select_tie | R Documentation |
These functions return logical vectors the length of the ties in a network:
tie_is_random() marks one or more ties at random.
tie_is_max() and tie_is_min() are more useful
for converting the results from some tie measure into a mark-class object.
They can be particularly useful for highlighting which tie or ties
are key because they minimise or, more often, maximise some measure.
tie_is_random(.data, select = 1)
tie_is_max(tie_measure)
tie_is_min(tie_measure)
.data |
A network object of class |
select |
Number of elements to select (as TRUE). |
tie_measure |
An object created by a |
A tie_mark logical vector the length of the ties in the network,
giving either TRUE or FALSE for each tie depending on
whether the condition is matched.
Other marks:
mark_core,
mark_degree,
mark_diff,
mark_dyads,
mark_nodes,
mark_select_node,
mark_ties,
mark_triangles
Other tie:
mark_dyads,
mark_ties,
mark_triangles,
measure_broker_tie,
measure_centralities_between,
measure_centralities_close,
measure_centralities_degree,
measure_centralities_eigen
Other selection:
mark_select_node
tie_is_max(tie_by_betweenness(ison_brandes))
tie_is_min(tie_by_betweenness(ison_brandes))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.