These functions return logical vectors the length of the ties in a network:
tie_is_random() marks one or more ties at random.
tie_is_max() and tie_is_min() are more useful
for converting the results from some tie measure into a mark-class object.
They can be particularly useful for highlighting which tie or ties
are key because they minimise or, more often, maximise some measure.
tie_is_random(.data, size = 1)
tie_is_max(tie_measure)
tie_is_min(tie_measure)A network object of class mnet, igraph, tbl_graph, network, or similar.
For more information on the standard coercion possible,
see manynet::as_tidygraph().
The number of nodes to select (as TRUE).
An object created by a tie_ measure.
Other marks:
mark_degree,
mark_diff,
mark_nodes,
mark_select,
mark_ties,
mark_triangles
# tie_is_max(tie_by_betweenness(ison_brandes))
#tie_is_min(tie_by_betweenness(ison_brandes))