| mark_ties | R Documentation |
These functions return logical vectors the length of the ties in a network identifying which hold certain properties or positions in the network.
tie_is_loop() marks ties that are loops.
tie_is_feedback() marks ties that are feedback arcs causing the network to not be acyclic.
tie_is_bridge() marks ties that cut or act as articulation points in a network.
tie_is_path() marks ties on a path from one node to another.
They are most useful in highlighting parts of the network that are particularly well- or poorly-connected.
tie_is_loop(.data)
tie_is_feedback(.data)
tie_is_bridge(.data)
tie_is_path(.data, from, to, all_paths = FALSE)
.data |
A network object of class |
from |
The index or name of the node from which the path should start. |
to |
The index or name of the node to which the path should be traced. |
all_paths |
Whether to return a list of paths or sample just one. By default FALSE, sampling just a single path. |
A tie_mark logical vector the length of the ties in the network,
giving either TRUE or FALSE for each tie depending on
whether the condition is matched.
Other marks:
mark_core,
mark_degree,
mark_diff,
mark_dyads,
mark_nodes,
mark_select_node,
mark_select_tie,
mark_triangles
Other tie:
mark_dyads,
mark_select_tie,
mark_triangles,
measure_broker_tie,
measure_centralities_between,
measure_centralities_close,
measure_centralities_degree,
measure_centralities_eigen
tie_is_loop(fict_marvel)
tie_is_feedback(ison_algebra)
tie_is_bridge(ison_brandes)
ison_adolescents |>
mutate_ties(route = tie_is_path(from = "Jane", to = 7))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.