| mark_triangles | R Documentation |
These functions return logical vectors the length of the ties in a network identifying which hold certain properties or positions in the network.
tie_is_triangular() marks ties that are part of triangles.
tie_is_cyclical() marks ties that are part of cycles.
tie_is_triplet() marks ties that are part of transitive triplets.
tie_is_simmelian() marks ties that are both in a triangle
and fully reciprocated.
tie_is_imbalanced() marks ties that are part of imbalanced triads.
tie_is_transitive() marks ties that complete transitive closure.
They are most useful in highlighting parts of the network that are cohesively connected.
tie_is_triangular(.data)
tie_is_transitive(.data)
tie_is_triplet(.data)
tie_is_cyclical(.data)
tie_is_simmelian(.data)
tie_is_imbalanced(.data)
.data |
A network object of class |
A tie_mark logical vector the length of the ties in the network,
giving either TRUE or FALSE for each tie depending on
whether the condition is matched.
Other marks:
mark_core,
mark_degree,
mark_diff,
mark_dyads,
mark_nodes,
mark_select_node,
mark_select_tie,
mark_ties
Other tie:
mark_dyads,
mark_select_tie,
mark_ties,
measure_broker_tie,
measure_centralities_between,
measure_centralities_close,
measure_centralities_degree,
measure_centralities_eigen
Other cohesion:
measure_breadth,
measure_cohesion,
measure_fragmentation,
motif_net,
motif_node
ison_monks |> to_uniplex("like") |>
mutate_ties(tri = tie_is_triangular())
ison_adolescents |> to_directed() |>
mutate_ties(trans = tie_is_transitive())
ison_adolescents |> to_directed() |>
mutate_ties(trip = tie_is_triplet())
ison_adolescents |> to_directed() |>
mutate_ties(cyc = tie_is_cyclical())
ison_monks |> to_uniplex("like") |>
mutate_ties(simmel = tie_is_simmelian())
fict_marvel |> to_uniplex("relationship") |> tie_is_imbalanced()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.