| measure_assort_net | R Documentation |
These functions offer ways to measure the distribution or assortativity of ties in a network:
net_by_heterophily() measures how embedded nodes in the network
are within groups of nodes with the same attribute.
net_by_homophily() measures how embedded nodes in the network
are within groups of nodes with the same attribute, but with more options for method.
net_by_assortativity() measures the degree assortativity in a network.
net_by_spatial() measures the spatial association/autocorrelation
(global Moran's I) in a network.
Note that for two-mode networks, homophily is calculated on the mode with the attribute of interest, and the other mode is ignored. If the attribute is present on both modes, homophily is calculated on the first mode by default, but a message is given and the user can choose to calculate homophily on the other mode instead by subsetting the attribute vector and converting the network to a one-mode network.
net_by_heterophily(.data, attribute)
net_by_homophily(
.data,
attribute,
assortativity = c("ie", "ei", "yule", "geary")
)
net_by_assortativity(.data)
net_by_spatial(.data, attribute)
.data |
A network object of class |
attribute |
Name of a nodal attribute, mark, measure, or membership vector. |
assortativity |
Which method to use for Yule's Q is a measure of association for two binary variables, calculated as:
where Geary's C is a measure of spatial autocorrelation, calculated as:
where |
A network_measure numeric score.
Given a partition of a network into a number of mutually exclusive groups then The E-I index is the number of ties between (or external) nodes grouped in some mutually exclusive categories minus the number of ties within (or internal) these groups divided by the total number of ties. This value can range from 1 to -1, where 1 indicates ties only between categories/groups and -1 ties only within categories/groups.
Krackhardt, David, and Robert N. Stern. 1988. Informal networks and organizational crises: an experimental simulation. Social Psychology Quarterly 51(2): 123-140. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.2307/2786835")}
McPherson, Miller, Lynn Smith-Lovin, and James M. Cook. 2001. "Birds of a Feather: Homophily in Social Networks". Annual Review of Sociology, 27(1): 415-444. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1146/annurev.soc.27.1.415")}
Newman, Mark E.J. 2002. "Assortative mixing in networks". Physical Review Letters, 89(20): 208701. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1103/physrevlett.89.208701")}
Moran, Patrick Alfred Pierce. 1950. "Notes on continuous stochastic phenomena". Biometrika 37(1): 17-23. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.2307/2332142")}
Other diversity:
measure_assort_node,
measure_diverse_net,
measure_diverse_node
Other measures:
measure_assort_node,
measure_breadth,
measure_broker_node,
measure_broker_tie,
measure_brokerage,
measure_central_between,
measure_central_close,
measure_central_degree,
measure_central_eigen,
measure_centralities_between,
measure_centralities_close,
measure_centralities_degree,
measure_centralities_eigen,
measure_closure,
measure_closure_node,
measure_cohesion,
measure_core,
measure_diffusion_infection,
measure_diffusion_net,
measure_diffusion_node,
measure_diverse_net,
measure_diverse_node,
measure_features,
measure_fragmentation,
measure_hierarchy,
measure_periods
marvel_friends <- to_unsigned(to_uniplex(fict_marvel, "relationship"), "positive")
net_by_heterophily(marvel_friends, "Gender")
net_by_heterophily(marvel_friends, "Attractive")
net_by_homophily(marvel_friends, "Gender")
net_by_assortativity(ison_networkers)
net_by_spatial(ison_lawfirm, "age")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.