These functions return values or vectors relating to how broad a network is.

  • net_diameter() measures the maximum path length in the network.

  • net_length() measures the average path length in the network.

net_by_diameter(.data)

net_by_length(.data)

Arguments

.data

A network object of class mnet, igraph, tbl_graph, network, or similar. For more information on the standard coercion possible, see manynet::as_tidygraph().

Examples

net_by_diameter(fict_marvel)
#> [1] 4
net_by_diameter(to_giant(fict_marvel))
#> [1] 4
net_by_length(fict_marvel)
#> [1] 2.41
net_by_length(to_giant(fict_marvel))
#> [1] 2.41