tie_by_cohesion() measures the ratio between common neighbors to ties'
adjacent nodes and the total number of adjacent nodes,
where high values indicate ties' embeddedness in dense local environments.
tie_by_cohesion(.data)A network object of class mnet, igraph, tbl_graph, network, or similar.
For more information on the standard coercion possible,
see manynet::as_tidygraph().
A tie_measure numeric vector the length of the ties in the network,
providing the scores for each tie.
If the network is labelled,
then the scores will be labelled with the ties' adjacent nodes' names.
Other brokerage:
measure_broker_node,
measure_brokerage,
member_brokerage,
motif_brokerage_net,
motif_brokerage_node
Other measures:
measure_assort_net,
measure_assort_node,
measure_breadth,
measure_broker_node,
measure_brokerage,
measure_central_between,
measure_central_close,
measure_central_degree,
measure_central_eigen,
measure_centralisation_between,
measure_centralisation_close,
measure_centralisation_degree,
measure_centralisation_eigen,
measure_centralities_between,
measure_centralities_close,
measure_centralities_degree,
measure_centralities_eigen,
measure_closure,
measure_closure_node,
measure_cohesion,
measure_core,
measure_diffusion_infection,
measure_diffusion_net,
measure_diffusion_node,
measure_diverse_net,
measure_diverse_node,
measure_features,
measure_fragmentation,
measure_hierarchy,
measure_periods
Other tie:
mark_dyads,
mark_select_tie,
mark_ties,
mark_triangles,
measure_centralities_between,
measure_centralities_close,
measure_centralities_degree,
measure_centralities_eigen