These functions include ways to measure nodes' brokerage activity and exclusivity in a network:

  • node_brokering_activity() measures nodes' brokerage activity.

  • node_brokering_exclusivity() measures nodes' brokerage exclusivity.

node_by_brokering_activity(.data, membership)

node_by_brokering_exclusivity(.data, membership)

Arguments

.data

A network object of class mnet, igraph, tbl_graph, network, or similar. For more information on the standard coercion possible, see manynet::as_tidygraph().

membership

A vector of partition membership as integers.

References

On brokerage activity and exclusivity

Hamilton, Matthew, Jacob Hileman, and Orjan Bodin. 2020. "Evaluating heterogeneous brokerage: New conceptual and methodological approaches and their application to multi-level environmental governance networks" Social Networks 61: 1-10. doi:10.1016/j.socnet.2019.08.002

Examples

node_by_brokering_exclusivity(ison_networkers, "Discipline")
#> █▁▁▁▁▁ 
#>   `Lin Freeman` `Doug White` `Ev Rogers` `Richard Alba` `Phipps Arabie`
#> 1             1            0           0              0               0
#> # ... and 27 more values from this nodeset. Use `print_all(...)` to print all values.