measure_centralisation_close: Measuring networks closeness-like centralisation

measure_centralisation_closeR Documentation

Measuring networks closeness-like centralisation

Description

  • net_by_closeness() measures a network's closeness centralization as a single score.

  • mode_by_closeness() measures closeness centralization separately for each mode of a two-mode network, returning one score per mode (following Borgatti and Everett, 1997).

  • net_by_reach() measures a network's reach centralization.

  • net_by_harmonic() measures a network's harmonic centralization.

All measures attempt to use as much information as they are offered, including whether the networks are directed, weighted, or multimodal. If this would produce unintended results, first transform the salient properties using e.g. to_undirected() functions. All centrality and centralization measures return normalized measures by default, including for two-mode networks.

For two-mode networks the two modes have different theoretical maxima, so net_by_closeness() reports a single network-level score by applying Freeman's general centralization index over the normalized node closeness scores, whereas mode_by_closeness() reports the per-mode scores directly.

Usage

net_by_closeness(.data, normalized = TRUE, direction = c("all", "out", "in"))

mode_by_closeness(.data, normalized = TRUE, direction = c("all", "out", "in"))

net_by_reach(.data, normalized = TRUE, cutoff = 2)

net_by_harmonic(.data, normalized = TRUE, cutoff = 2)

Arguments

.data

A network object of class mnet, igraph, tbl_graph, network, or similar. For more information on the standard coercion possible, see manynet::as_tidygraph().

normalized

Logical scalar, whether scores are normalized. Different denominators may be used depending on the measure, whether the object is one-mode or two-mode, and other arguments. By default TRUE.

direction

Character string, “out” bases the measure on outgoing ties, “in” on incoming ties, and "all" on either/the sum of the two. By default "all".

cutoff

The maximum path length to consider when calculating betweenness. If negative or NULL (the default), there's no limit to the path lengths considered.

Value

⁠net_by_*()⁠ functions return a network_measure scalar; mode_by_closeness() returns a mode_measure numeric vector of length two, giving one centralization score per mode.

References

Borgatti, Stephen P., and Martin G. Everett. 1997. "Network analysis of 2-mode data." Social Networks 19(3): 243-269. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/S0378-8733(96)00301-2")}

See Also

Other closeness: measure_central_close, measure_centralities_close

Other centrality: measure_central_between, measure_central_close, measure_central_degree, measure_central_eigen, measure_centralisation_between, measure_centralisation_degree, measure_centralisation_eigen, measure_centralities_between, measure_centralities_close, measure_centralities_degree, measure_centralities_eigen

Examples

net_by_closeness(ison_southern_women, direction = "in")
mode_by_closeness(ison_southern_women, direction = "in")

netrics documentation built on July 24, 2026, 5:07 p.m.