R/measure_centrality_closeness.R
measure_centralisation_close.Rdnet_by_closeness() measures a network's closeness centralization.
net_by_reach() measures a network's reach centralization.
net_by_harmonic() measures a network's harmonic centralization.
All measures attempt to use as much information as they are offered,
including whether the networks are directed, weighted, or multimodal.
If this would produce unintended results,
first transform the salient properties using e.g. manynet::to_undirected() functions.
All centrality and centralization measures return normalized measures by default,
including for two-mode networks.
net_by_closeness(.data, normalized = TRUE, direction = c("all", "out", "in"))
net_by_reach(.data, normalized = TRUE, cutoff = 2)
net_by_harmonic(.data, normalized = TRUE, cutoff = 2)A network object of class mnet, igraph, tbl_graph, network, or similar.
For more information on the standard coercion possible,
see manynet::as_tidygraph().
Logical scalar, whether scores are normalized. Different denominators may be used depending on the measure, whether the object is one-mode or two-mode, and other arguments. By default TRUE.
Character string, “out” bases the measure on outgoing ties, “in” on incoming ties, and "all" on either/the sum of the two. By default "all".
The maximum path length to consider when calculating betweenness. If negative or NULL (the default), there's no limit to the path lengths considered.
A network_measure numeric score.
Other closeness:
measure_central_close,
measure_centralities_close
Other centrality:
measure_central_between,
measure_central_close,
measure_central_degree,
measure_central_eigen,
measure_centralisation_between,
measure_centralisation_degree,
measure_centralisation_eigen,
measure_centralities_between,
measure_centralities_close,
measure_centralities_degree,
measure_centralities_eigen
Other measures:
measure_assort_net,
measure_assort_node,
measure_breadth,
measure_broker_node,
measure_broker_tie,
measure_brokerage,
measure_central_between,
measure_central_close,
measure_central_degree,
measure_central_eigen,
measure_centralisation_between,
measure_centralisation_degree,
measure_centralisation_eigen,
measure_centralities_between,
measure_centralities_close,
measure_centralities_degree,
measure_centralities_eigen,
measure_closure,
measure_closure_node,
measure_cohesion,
measure_core,
measure_diffusion_infection,
measure_diffusion_net,
measure_diffusion_node,
measure_diverse_net,
measure_diverse_node,
measure_features,
measure_fragmentation,
measure_hierarchy,
measure_periods
net_by_closeness(ison_southern_women, direction = "in")
#> Mode 1 Mode 2
#> 0.224 0.537