R/measure_centrality_degree.R
measure_centralisation_degree.Rdnet_by_degree() measures a network's degree centralization;
there are several related shortcut functions:
net_by_indegree() returns the direction = 'in' results.
net_by_outdegree() returns the direction = 'out' results.
All measures attempt to use as much information as they are offered,
including whether the networks are directed, weighted, or multimodal.
If this would produce unintended results,
first transform the salient properties using e.g. manynet::to_undirected() functions.
All centrality and centralization measures return normalized measures
by default, including for two-mode networks.
For two-mode networks, "all" uses as numerator the sum of differences between the maximum centrality score for the mode against all other centrality scores in the network, whereas "in" uses as numerator the sum of differences between the maximum centrality score for the mode against only the centrality scores of the other nodes in that mode.
net_by_degree(.data, normalized = TRUE, direction = c("all", "out", "in"))
net_by_outdegree(.data, normalized = TRUE)
net_by_indegree(.data, normalized = TRUE)A network object of class mnet, igraph, tbl_graph, network, or similar.
For more information on the standard coercion possible,
see manynet::as_tidygraph().
Logical scalar, whether scores are normalized. Different denominators may be used depending on the measure, whether the object is one-mode or two-mode, and other arguments. By default TRUE.
Character string, “out” bases the measure on outgoing ties, “in” on incoming ties, and "all" on either/the sum of the two. By default "all".
A network_measure numeric score.
Other degree:
mark_degree,
measure_central_degree,
measure_centralities_degree
Other centrality:
measure_central_between,
measure_central_close,
measure_central_degree,
measure_central_eigen,
measure_centralisation_between,
measure_centralisation_close,
measure_centralisation_eigen,
measure_centralities_between,
measure_centralities_close,
measure_centralities_degree,
measure_centralities_eigen
Other measures:
measure_assort_net,
measure_assort_node,
measure_breadth,
measure_broker_node,
measure_broker_tie,
measure_brokerage,
measure_central_between,
measure_central_close,
measure_central_degree,
measure_central_eigen,
measure_centralisation_between,
measure_centralisation_close,
measure_centralisation_eigen,
measure_centralities_between,
measure_centralities_close,
measure_centralities_degree,
measure_centralities_eigen,
measure_closure,
measure_closure_node,
measure_cohesion,
measure_core,
measure_diffusion_infection,
measure_diffusion_net,
measure_diffusion_node,
measure_diverse_net,
measure_diverse_node,
measure_features,
measure_fragmentation,
measure_hierarchy,
measure_periods
net_by_degree(ison_southern_women, direction = "in")
#> Mode 1 Mode 2
#> 0.249 0.484