| measure_centralisation_eigen | R Documentation |
net_by_eigenvector() measures the eigenvector centralization for a
network as a single score.
mode_by_eigenvector() measures eigenvector centralization separately for
each mode of a two-mode network (via projection to each mode), returning one
score per mode (following Borgatti and Everett, 1997).
All measures attempt to use as much information as they are offered,
including whether the networks are directed, weighted, or multimodal.
If this would produce unintended results,
first transform the salient properties using e.g. to_undirected() functions.
All centrality and centralization measures return normalized measures
by default, including for two-mode networks.
For two-mode networks the two modes have different theoretical maxima, so
net_by_eigenvector() reports a single network-level score by applying
Freeman's general centralization index over the normalized node eigenvector
scores, whereas mode_by_eigenvector() reports the per-mode scores directly.
net_by_eigenvector(.data, normalized = TRUE)
mode_by_eigenvector(.data, normalized = TRUE)
.data |
A network object of class |
normalized |
Logical scalar, whether scores are normalized. Different denominators may be used depending on the measure, whether the object is one-mode or two-mode, and other arguments. By default TRUE. |
net_by_eigenvector() returns a network_measure scalar;
mode_by_eigenvector() returns a mode_measure numeric vector of length two,
giving one centralization score per mode.
Borgatti, Stephen P., and Martin G. Everett. 1997. "Network analysis of 2-mode data." Social Networks 19(3): 243-269. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/S0378-8733(96)00301-2")}
Other eigenvector:
measure_central_eigen,
measure_centralities_eigen
Other centrality:
measure_central_between,
measure_central_close,
measure_central_degree,
measure_central_eigen,
measure_centralisation_between,
measure_centralisation_close,
measure_centralisation_degree,
measure_centralities_between,
measure_centralities_close,
measure_centralities_degree,
measure_centralities_eigen
net_by_eigenvector(ison_southern_women)
mode_by_eigenvector(ison_southern_women)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.