R/measure_centrality_closeness.R
measure_centralities_close.Rdtie_by_closeness() measures the closeness of each tie to other ties
in the network.
All measures attempt to use as much information as they are offered,
including whether the networks are directed, weighted, or multimodal.
If this would produce unintended results,
first transform the salient properties using e.g. manynet::to_undirected() functions.
All centrality and centralization measures return normalized measures by default,
including for two-mode networks.
tie_by_closeness(.data, normalized = TRUE)A network object of class mnet, igraph, tbl_graph, network, or similar.
For more information on the standard coercion possible,
see manynet::as_tidygraph().
Logical scalar, whether scores are normalized. Different denominators may be used depending on the measure, whether the object is one-mode or two-mode, and other arguments. By default TRUE.
A tie_measure numeric vector the length of the ties in the network,
providing the scores for each tie.
If the network is labelled,
then the scores will be labelled with the ties' adjacent nodes' names.
Other closeness:
measure_central_close,
measure_centralisation_close
Other centrality:
measure_central_between,
measure_central_close,
measure_central_degree,
measure_central_eigen,
measure_centralisation_between,
measure_centralisation_close,
measure_centralisation_degree,
measure_centralisation_eigen,
measure_centralities_between,
measure_centralities_degree,
measure_centralities_eigen
Other measures:
measure_assort_net,
measure_assort_node,
measure_breadth,
measure_broker_node,
measure_broker_tie,
measure_brokerage,
measure_central_between,
measure_central_close,
measure_central_degree,
measure_central_eigen,
measure_centralisation_between,
measure_centralisation_close,
measure_centralisation_degree,
measure_centralisation_eigen,
measure_centralities_between,
measure_centralities_degree,
measure_centralities_eigen,
measure_closure,
measure_closure_node,
measure_cohesion,
measure_core,
measure_diffusion_infection,
measure_diffusion_net,
measure_diffusion_node,
measure_diverse_net,
measure_diverse_node,
measure_features,
measure_fragmentation,
measure_hierarchy,
measure_periods
Other tie:
mark_dyads,
mark_select_tie,
mark_ties,
mark_triangles,
measure_broker_tie,
measure_centralities_between,
measure_centralities_degree,
measure_centralities_eigen
(ec <- tie_by_closeness(ison_adolescents))
#> `Betty-Sue` `Sue-Alice` `Alice-Jane` `Sue-Dale` `Alice-Dale` `Jane-Dale`
#> 1 0.562 0.692 0.6 0.643 0.643 0.5
#> # ... and 4 more values from this nodeset. Use `print_all(...)` to print all values.
ison_adolescents %>% mutate_ties(weight = ec)
#>
#> ── # The Adolescent Society ────────────────────────────────────────────────────
#> # A labelled, weighted, undirected network of 8 adolescents and 10 friendships
#> ties
#>
#> ── Nodes
#> # A tibble: 8 × 1
#> name
#> <chr>
#> 1 Betty
#> 2 Sue
#> 3 Alice
#> 4 Jane
#> 5 Dale
#> 6 Pam
#> # ℹ 2 more rows
#>
#> ── Ties
#> # A tibble: 10 × 3
#> from to weight
#> <int> <int> <tie_mesr>
#> 1 1 2 0.5625000
#> 2 2 3 0.6923077
#> 3 3 4 0.6000000
#> 4 2 5 0.6428571
#> 5 3 5 0.6428571
#> 6 4 5 0.5000000
#> # ℹ 4 more rows
#>