These functions offer methods for summarising the closure in configurations in one-, two-, and three-mode networks:

  • net_reciprocity() measures reciprocity in a (usually directed) network.

  • node_reciprocity() measures nodes' reciprocity.

  • net_transitivity() measures transitivity in a network.

  • node_transitivity() measures nodes' transitivity.

  • net_equivalency() measures equivalence or reinforcement in a (usually two-mode) network.

  • net_congruency() measures congruency across two two-mode networks.

net_by_reciprocity(.data, method = "default")

node_by_reciprocity(.data)

net_by_transitivity(.data)

node_by_transitivity(.data)

net_by_equivalency(.data)

node_by_equivalency(.data)

net_by_congruency(.data, object2)

Arguments

.data

A network object of class mnet, igraph, tbl_graph, network, or similar. For more information on the standard coercion possible, see manynet::as_tidygraph().

method

For reciprocity, either default or ratio. See ?igraph::reciprocity

object2

Optionally, a second (two-mode) matrix, igraph, or tidygraph

Details

For one-mode networks, shallow wrappers of igraph versions exist via net_reciprocity and net_transitivity.

For two-mode networks, net_equivalency calculates the proportion of three-paths in the network that are closed by fourth tie to establish a "shared four-cycle" structure.

For three-mode networks, net_congruency calculates the proportion of three-paths spanning two two-mode networks that are closed by a fourth tie to establish a "congruent four-cycle" structure.

Equivalency

The net_by_equivalency() function calculates the Robins and Alexander (2004) clustering coefficient for two-mode networks. Note that for weighted two-mode networks, the result is divided by the average tie weight.

References

On equivalency or four-cycles

Robins, Garry L, and Malcolm Alexander. 2004. Small worlds among interlocking directors: Network structure and distance in bipartite graphs. Computational & Mathematical Organization Theory 10(1): 69–94. doi:10.1023/B:CMOT.0000032580.12184.c0 .

On congruency

Knoke, David, Mario Diani, James Hollway, and Dimitris C Christopoulos. 2021. Multimodal Political Networks. Cambridge University Press. Cambridge University Press. doi:10.1017/9781108985000

Examples

net_by_reciprocity(ison_southern_women)
#> [1] 1
node_by_reciprocity(to_unweighted(ison_networkers))
#> ▁▁▁▁▁▂▃▃ 
#>   `Lin Freeman` `Doug White` `Ev Rogers` `Richard Alba` `Phipps Arabie`
#> 1         0.935         0.75           1          0.944           0.286
#> # ... and 27 more values from this nodeset. Use `print_all(...)` to print all values.
net_by_transitivity(ison_adolescents)
#> [1] 0.45
node_by_transitivity(ison_adolescents)
#> ▂▃▂▂▂ 
#>   Betty   Sue Alice  Jane  Dale   Pam Carol  Tina
#> 1   NaN 0.333   0.5     1 0.667 0.333     0   NaN
net_by_equivalency(ison_southern_women)
#> [1] 0.468
# node_by_equivalency(ison_southern_women)