| measure_closure_node | R Documentation |
These functions offer methods for summarising the closure in configurations in one- and two-mode networks:
node_by_reciprocity() measures nodes' reciprocity.
node_by_transitivity() measures nodes' transitivity.
node_by_equivalency() measures nodes' equivalence or reinforcement
in a (usually two-mode) network.
node_by_reciprocity(.data)
node_by_transitivity(.data)
node_by_equivalency(.data)
.data |
A network object of class |
For one-mode networks, shallow wrappers of igraph versions exist via
node_by_reciprocity and node_by_transitivity.
For two-mode networks, node_by_equivalency calculates the proportion of three-paths in the network
that are closed by fourth tie to establish a "shared four-cycle" structure.
A node_measure numeric vector the length of the nodes in the network,
providing the scores for each node.
If the network is labelled,
then the scores will be labelled with the nodes' names.
Other measures:
measure_assort_net,
measure_assort_node,
measure_breadth,
measure_broker_node,
measure_broker_tie,
measure_brokerage,
measure_central_between,
measure_central_close,
measure_central_degree,
measure_central_eigen,
measure_centralities_between,
measure_centralities_close,
measure_centralities_degree,
measure_centralities_eigen,
measure_closure,
measure_cohesion,
measure_core,
measure_diffusion_infection,
measure_diffusion_net,
measure_diffusion_node,
measure_diverse_net,
measure_diverse_node,
measure_features,
measure_fragmentation,
measure_hierarchy,
measure_periods
Other nodal:
mark_core,
mark_degree,
mark_diff,
mark_nodes,
mark_select_node,
measure_assort_node,
measure_broker_node,
measure_brokerage,
measure_central_between,
measure_central_close,
measure_central_degree,
measure_central_eigen,
measure_core,
measure_diffusion_node,
measure_diverse_node,
member_brokerage,
member_cliques,
member_community,
member_community_hier,
member_community_non,
member_components,
member_core,
member_diffusion,
member_equivalence,
motif_brokerage_node,
motif_exposure,
motif_node,
motif_path
node_by_reciprocity(to_unweighted(ison_networkers))
node_by_transitivity(ison_adolescents)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.