These functions offer methods for summarising the closure in configurations in one- and two-mode networks:

  • node_by_reciprocity() measures nodes' reciprocity.

  • node_by_transitivity() measures nodes' transitivity.

  • node_by_equivalency() measures nodes' equivalence or reinforcement in a (usually two-mode) network.

node_by_reciprocity(.data)

node_by_transitivity(.data)

node_by_equivalency(.data)

Arguments

.data

A network object of class mnet, igraph, tbl_graph, network, or similar. For more information on the standard coercion possible, see manynet::as_tidygraph().

Value

A node_measure numeric vector the length of the nodes in the network, providing the scores for each node. If the network is labelled, then the scores will be labelled with the nodes' names.

Details

For one-mode networks, shallow wrappers of igraph versions exist via node_by_reciprocity and node_by_transitivity.

For two-mode networks, node_by_equivalency calculates the proportion of three-paths in the network that are closed by fourth tie to establish a "shared four-cycle" structure.

Examples

node_by_reciprocity(to_unweighted(ison_networkers))
#> ▁▁▁▁▁▂▃▃ 
#>   `Lin Freeman` `Doug White` `Ev Rogers` `Richard Alba` `Phipps Arabie`
#> 1         0.935         0.75           1          0.944           0.286
#> # ... and 27 more values from this nodeset. Use `print_all(...)` to print all values.
node_by_transitivity(ison_adolescents)
#> ▂▃▂▂▂ 
#>   Betty   Sue Alice  Jane  Dale   Pam Carol  Tina
#> 1   NaN 0.333   0.5     1 0.667 0.333     0   NaN