These functions return values or vectors relating to how cohesive a network is:

  • net_by_density() measures the ratio of ties to the number of possible ties.

  • net_by_components() measures the number of (strong) components in the network.

  • net_by_independence() measures the independence number, or size of the largest independent set in the network.

net_by_density(.data)

net_by_components(.data)

net_by_independence(.data)

Arguments

.data

A network object of class mnet, igraph, tbl_graph, network, or similar. For more information on the standard coercion possible, see manynet::as_tidygraph().

Value

A network_measure numeric score.

Components

To get the 'weak' components of a directed graph, please use manynet::to_undirected() first.

Examples

net_by_density(ison_adolescents)
#> [1] 0.357
net_by_density(ison_southern_women)
#> [1] 0.353
  net_by_components(fict_thrones)
#> [1] 130
  net_by_components(to_undirected(fict_thrones))
#> [1] 2
net_by_independence(ison_adolescents)
#> [1] 4