These functions return values or vectors relating to how cohesive a network is:
net_by_density() measures the ratio of ties to the number
of possible ties.
net_by_components() measures the number of (strong) components
in the network.
net_by_independence() measures the independence number,
or size of the largest independent set in the network.
net_by_density(.data)
net_by_components(.data)
net_by_independence(.data)A network object of class mnet, igraph, tbl_graph, network, or similar.
For more information on the standard coercion possible,
see manynet::as_tidygraph().
A network_measure numeric score.
To get the 'weak' components of a directed graph,
please use manynet::to_undirected() first.
Other cohesion:
mark_triangles,
measure_breadth,
measure_fragmentation,
motif_net,
motif_node
Other measures:
measure_assort_net,
measure_assort_node,
measure_breadth,
measure_broker_node,
measure_broker_tie,
measure_brokerage,
measure_central_between,
measure_central_close,
measure_central_degree,
measure_central_eigen,
measure_centralisation_between,
measure_centralisation_close,
measure_centralisation_degree,
measure_centralisation_eigen,
measure_centralities_between,
measure_centralities_close,
measure_centralities_degree,
measure_centralities_eigen,
measure_closure,
measure_closure_node,
measure_core,
measure_diffusion_infection,
measure_diffusion_net,
measure_diffusion_node,
measure_diverse_net,
measure_diverse_node,
measure_features,
measure_fragmentation,
measure_hierarchy,
measure_periods
net_by_density(ison_adolescents)
#> [1] 0.357
net_by_density(ison_southern_women)
#> [1] 0.353
net_by_components(fict_thrones)
#> [1] 130
net_by_components(to_undirected(fict_thrones))
#> [1] 2
net_by_independence(ison_adolescents)
#> [1] 4