These functions return values or vectors relating to how cohesive a network is:
net_density() measures the ratio of ties to the number
of possible ties.
net_components() measures the number of (strong) components
in the network.
net_cohesion() measures the minimum number of nodes to remove
from the network needed to increase the number of components.
net_adhesion() measures the minimum number of ties to remove
from the network needed to increase the number of components.
net_diameter() measures the maximum path length in the network.
net_length() measures the average path length in the network.
net_independence() measures the independence number,
or size of the largest independent set in the network.
net_strength() measures the number of ties that would need to be
removed from a network to increase its number of components.
net_toughness() measures the number of nodes that would need to be
removed from a network to increase its number of components.
net_by_density(.data)
net_by_components(.data)
net_by_independence(.data)A network object of class mnet, igraph, tbl_graph, network, or similar.
For more information on the standard coercion possible,
see manynet::as_tidygraph().
To get the 'weak' components of a directed graph,
please use manynet::to_undirected() first.
Other measures:
measure_assortativity,
measure_breadth,
measure_brokerage,
measure_central_between,
measure_central_close,
measure_central_degree,
measure_central_eigen,
measure_closure,
measure_diffusion_infection,
measure_diffusion_net,
measure_diffusion_node,
measure_features,
measure_fragmentation,
measure_heterogeneity,
measure_hierarchy,
measure_holes,
measure_periods,
member_diffusion
Other cohesion:
mark_triangles,
measure_breadth,
measure_fragmentation
net_by_density(ison_adolescents)
#> [1] 0.357
net_by_density(ison_southern_women)
#> [1] 0.353
net_by_components(fict_thrones)
#> [1] 130
net_by_components(to_undirected(fict_thrones))
#> [1] 2
net_by_independence(ison_adolescents)
#> [1] 4