| measure_core | R Documentation |
These functions identify nodes belonging to (some level of) the core of a network:
node_by_coreness() returns a continuous measure of how closely each node
resembles a typical core node.
node_by_kcoreness() assigns nodes to their level of k-coreness.
node_by_kcoreness(.data)
node_by_coreness(.data)
.data |
A network object of class |
A node_measure numeric vector the length of the nodes in the network,
providing the scores for each node.
If the network is labelled,
then the scores will be labelled with the nodes' names.
k-coreness captures the maximal subgraphs in which each vertex has at least
degree k, where k is also the order of the subgraph.
As described in igraph::coreness,
a node's coreness is k if it belongs to the k-core
but not to the (k+1)-core.
Seidman, Stephen B. 1983. "Network structure and minimum degree". Social Networks, 5(3), 269-287. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/0378-8733(83)90028-X")}
Batagelj, Vladimir, and Matjaz Zaversnik. 2003. "An O(m) algorithm for cores decomposition of networks". arXiv preprint cs/0310049. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.48550/arXiv.cs/0310049")}
Other core-periphery:
mark_core,
member_core
Other measures:
measure_assort_net,
measure_assort_node,
measure_breadth,
measure_broker_node,
measure_broker_tie,
measure_brokerage,
measure_central_between,
measure_central_close,
measure_central_degree,
measure_central_eigen,
measure_centralities_between,
measure_centralities_close,
measure_centralities_degree,
measure_centralities_eigen,
measure_closure,
measure_closure_node,
measure_cohesion,
measure_diffusion_infection,
measure_diffusion_net,
measure_diffusion_node,
measure_diverse_net,
measure_diverse_node,
measure_features,
measure_fragmentation,
measure_hierarchy,
measure_periods
Other nodal:
mark_core,
mark_degree,
mark_diff,
mark_nodes,
mark_select_node,
measure_assort_node,
measure_broker_node,
measure_brokerage,
measure_central_between,
measure_central_close,
measure_central_degree,
measure_central_eigen,
measure_closure_node,
measure_diffusion_node,
measure_diverse_node,
member_brokerage,
member_cliques,
member_community,
member_community_hier,
member_community_non,
member_components,
member_core,
member_diffusion,
member_equivalence,
motif_brokerage_node,
motif_exposure,
motif_node,
motif_path
node_by_kcoreness(ison_adolescents)
node_by_coreness(ison_adolescents)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.