These functions identify nodes belonging to (some level of) the core of a network:

  • node_by_coreness() returns a continuous measure of how closely each node resembles a typical core node.

  • node_by_kcoreness() assigns nodes to their level of k-coreness.

node_by_kcoreness(.data)

node_by_coreness(.data)

Arguments

.data

A network object of class mnet, igraph, tbl_graph, network, or similar. For more information on the standard coercion possible, see manynet::as_tidygraph().

Value

A node_measure numeric vector the length of the nodes in the network, providing the scores for each node. If the network is labelled, then the scores will be labelled with the nodes' names.

k-coreness

k-coreness captures the maximal subgraphs in which each vertex has at least degree k, where k is also the order of the subgraph. As described in igraph::coreness, a node's coreness is k if it belongs to the k-core but not to the (k+1)-core.

References

On k-coreness

Seidman, Stephen B. 1983. "Network structure and minimum degree". Social Networks, 5(3), 269-287. doi:10.1016/0378-8733(83)90028-X

Batagelj, Vladimir, and Matjaz Zaversnik. 2003. "An O(m) algorithm for cores decomposition of networks". arXiv preprint cs/0310049. doi:10.48550/arXiv.cs/0310049

Examples

node_by_kcoreness(ison_adolescents)
#> ▃▁▁▁▅ 
#>   Betty   Sue Alice  Jane  Dale   Pam Carol  Tina
#> 1     1     2     2     2     2     2     1     1
node_by_coreness(ison_adolescents)
#> ▃▁▁▁▃ 
#>   Betty   Sue Alice  Jane  Dale   Pam Carol  Tina
#> 1 0.181  0.89     1 0.562  0.82 0.619 0.071     0