These functions return values relating to how connected a network is and the number of nodes or edges to remove that would increase fragmentation.

  • net_cohesion() measures the minimum number of nodes to remove from the network needed to increase the number of components.

  • net_toughness() measures the number of nodes that would need to be removed from a network to increase its number of components.

  • net_adhesion() measures the minimum number of ties to remove from the network needed to increase the number of components.

  • net_strength() measures the number of ties that would need to be removed from a network to increase its number of components.

net_by_cohesion(.data)

net_by_adhesion(.data)

net_by_strength(.data)

net_by_toughness(.data)

Arguments

.data

A network object of class mnet, igraph, tbl_graph, network, or similar. For more information on the standard coercion possible, see manynet::as_tidygraph().

References

On cohesion

White, Douglas R and Frank Harary. 2001. "The Cohesiveness of Blocks In Social Networks: Node Connectivity and Conditional Density." Sociological Methodology 31(1): 305-59. doi:10.1111/0081-1750.00098

Examples

net_by_cohesion(fict_marvel)
#> [1] 2
net_by_cohesion(to_giant(fict_marvel))
#> [1] 2
net_by_adhesion(fict_marvel)
#> [1] 2
net_by_adhesion(to_giant(fict_marvel))
#> [1] 2
net_by_strength(ison_adolescents)
#> [1] 0.5
net_by_toughness(ison_adolescents)
#> [1] 0.5