net_by_waves() measures the number of waves in longitudinal network data.

net_by_waves(.data)

Arguments

.data

A network object of class mnet, igraph, tbl_graph, network, or similar. For more information on the standard coercion possible, see manynet::as_tidygraph().

Value

A network_measure numeric score.