These functions measure certain topological features of networks:

  • net_by_waves() measures the number of waves in longitudinal network data.

  • net_by_change() measures the Hamming distance between two or more networks.

  • net_by_stability() measures the Jaccard index of stability between two or more networks.

  • net_by_correlation() measures the product-moment correlation between two networks.

These net_*() functions return a numeric vector the length of the number of networks minus one. E.g., the periods between waves.

net_by_waves(.data)

net_by_change(.data, object2)

net_by_stability(.data, object2)

net_by_correlation(.data, object2)

Arguments

.data

A network object of class mnet, igraph, tbl_graph, network, or similar. For more information on the standard coercion possible, see manynet::as_tidygraph().

object2

A network object.