node_in_community() runs through all available community detection algorithms
for a given network type, finds the algorithm that returns the
largest modularity score, and returns the corresponding membership
partition.
Where feasible (a small enough network), the optimal problem solving
technique is used to ensure the maximal modularity partition.
For larger networks, it identifies the applicable algorithms and
finds the algorithm that maximises modularity and
returns that membership vector.
node_in_community(.data)A network object of class mnet, igraph, tbl_graph, network, or similar.
For more information on the standard coercion possible,
see manynet::as_tidygraph().
A node_member character vector the length of the nodes in the network,
of group memberships "A", "B", etc for each node.
If the network is labelled,
then the assignments will be labelled with the nodes' names.
Other community:
member_community_hier,
member_community_non
Other memberships:
member_brokerage,
member_cliques,
member_community_hier,
member_community_non,
member_components,
member_core,
member_diffusion,
member_equivalence
Other nodal:
mark_core,
mark_degree,
mark_diff,
mark_nodes,
mark_select_node,
measure_assort_node,
measure_broker_node,
measure_brokerage,
measure_central_between,
measure_central_close,
measure_central_degree,
measure_central_eigen,
measure_closure_node,
measure_core,
measure_diffusion_node,
measure_diverse_node,
member_brokerage,
member_cliques,
member_community_hier,
member_community_non,
member_components,
member_core,
member_diffusion,
member_equivalence,
motif_brokerage_node,
motif_exposure,
motif_node,
motif_path