| member_equivalence | R Documentation |
These functions combine an appropriate node_x_*() function
together with methods for calculating the hierarchical clusters
provided by a certain distance calculation.
node_in_equivalence() assigns nodes membership based on their equivalence
with respective to some motif/class.
The following functions call this function, together with an appropriate motif.
node_in_structural() assigns nodes membership based on their
having equivalent ties to the same other nodes.
node_in_regular() assigns nodes membership based on their
having equivalent patterns of ties.
node_in_automorphic() assigns nodes membership based on their
having equivalent distances to other nodes.
A plot() method exists for investigating the dendrogram
of the hierarchical cluster and showing the returned cluster
assignment.
node_in_equivalence(
.data,
motif,
k = c("silhouette", "elbow", "strict"),
cluster = c("hierarchical", "concor", "cosine"),
distance = c("euclidean", "maximum", "manhattan", "canberra", "binary", "minkowski"),
Kmax = 8L
)
node_in_structural(
.data,
k = c("silhouette", "elbow", "strict"),
cluster = c("hierarchical", "concor", "cosine"),
distance = c("euclidean", "maximum", "manhattan", "canberra", "binary", "minkowski"),
Kmax = 8L
)
node_in_regular(
.data,
k = c("silhouette", "elbow", "strict"),
cluster = c("hierarchical", "concor", "cosine"),
distance = c("euclidean", "maximum", "manhattan", "canberra", "binary", "minkowski"),
Kmax = 8L
)
node_in_automorphic(
.data,
k = c("silhouette", "elbow", "strict"),
cluster = c("hierarchical", "concor", "cosine"),
distance = c("euclidean", "maximum", "manhattan", "canberra", "binary", "minkowski"),
Kmax = 8L
)
.data |
A network object of class |
motif |
A matrix returned by a |
k |
Typically a character string indicating which method
should be used to select the number of clusters to return.
By default |
cluster |
Character string indicating whether clusters should be
clustered hierarchically ( |
distance |
Character string indicating which distance metric
to pass on to |
Kmax |
Integer indicating the maximum number of (k) clusters
to evaluate.
Ignored when |
A node_member character vector the length of the nodes in the network,
of group memberships "A", "B", etc for each node.
If the network is labelled,
then the assignments will be labelled with the nodes' names.
https://github.com/aslez/concoR
Other memberships:
member_brokerage,
member_cliques,
member_community,
member_community_hier,
member_community_non,
member_components,
member_core,
member_diffusion
Other nodal:
mark_core,
mark_degree,
mark_diff,
mark_nodes,
mark_select_node,
measure_assort_node,
measure_broker_node,
measure_brokerage,
measure_central_between,
measure_central_close,
measure_central_degree,
measure_central_eigen,
measure_closure_node,
measure_core,
measure_diffusion_node,
measure_diverse_node,
member_brokerage,
member_cliques,
member_community,
member_community_hier,
member_community_non,
member_components,
member_core,
member_diffusion,
motif_brokerage_node,
motif_exposure,
motif_node,
motif_path
(nse <- node_in_structural(ison_algebra))
(nre <- node_in_regular(ison_southern_women,
cluster = "concor"))
if(require("sna", quietly = TRUE)){
(nae <- node_in_automorphic(ison_southern_women,
k = "elbow"))
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.