net_x_brokerage() returns the Gould-Fernandez brokerage
roles in a network.
net_x_brokerage(.data, membership, standardized = FALSE)A network object of class mnet, igraph, tbl_graph, network, or similar.
For more information on the standard coercion possible,
see manynet::as_tidygraph().
A character string naming an existing node attribute in
the network, or a categorical vector of the same length as the number of
nodes in the network where each element indicates the group membership of
the corresponding node.
While this may often be a vector created using node_in_*() functions,
it can be any character vector that assigns nodes to groups or categories.
Whether the score should be standardized into a z-score indicating how many standard deviations above or below the average the score lies.
A network_motif named numeric vector or sometimes a data frame with
one row and a column for each motif type,
giving the count of each motif in the network.
This is printed as a tibble to avoid greedy printing of long vectors.
Other brokerage:
measure_broker_node,
measure_broker_tie,
measure_brokerage,
member_brokerage,
motif_brokerage_node
Other motifs:
motif_brokerage_node,
motif_exposure,
motif_hazard,
motif_hierarchy,
motif_net,
motif_node,
motif_path,
motif_periods
net_x_brokerage(ison_networkers, "Discipline")
#> # A tibble: 1 × 6
#> Coordinator Itinerant Gatekeeper Representative Liaison Total
#> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl>
#> 1 385 463 498 548 703 2597