| motif_brokerage_node | R Documentation |
node_x_brokerage() returns the Gould-Fernandez brokerage
roles played by nodes in a network.
node_x_brokerage(.data, membership, standardized = FALSE)
.data |
A network object of class |
membership |
A character string naming an existing node attribute in
the network, or a categorical vector of the same length as the number of
nodes in the network where each element indicates the group membership of
the corresponding node.
While this may often be a vector created using |
standardized |
Whether the score should be standardized into a z-score indicating how many standard deviations above or below the average the score lies. |
A node_motif matrix with one row for each node in the network and
a column for each motif type,
giving the count of each motif in which each node participates.
It is printed as a tibble, however, to avoid greedy printing.
If the network is labelled,
then the node names will be in a column named names.
Gould, Roger V., and Roberto M. Fernandez. 1989. “Structures of Mediation: A Formal Approach to Brokerage in Transaction Networks.” Sociological Methodology, 19: 89-126. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.2307/270949")}
Jasny, Lorien, and Mark Lubell. 2015. “Two-Mode Brokerage in Policy Networks.” Social Networks 41:36–47. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.socnet.2014.11.005")}
Other brokerage:
measure_broker_node,
measure_broker_tie,
measure_brokerage,
member_brokerage,
motif_brokerage_net
Other motifs:
motif_brokerage_net,
motif_exposure,
motif_hazard,
motif_hierarchy,
motif_net,
motif_node,
motif_path,
motif_periods
Other nodal:
mark_core,
mark_degree,
mark_diff,
mark_nodes,
mark_select_node,
measure_assort_node,
measure_broker_node,
measure_brokerage,
measure_central_between,
measure_central_close,
measure_central_degree,
measure_central_eigen,
measure_closure_node,
measure_core,
measure_diffusion_node,
measure_diverse_node,
member_brokerage,
member_cliques,
member_community,
member_community_hier,
member_community_non,
member_components,
member_core,
member_diffusion,
member_equivalence,
motif_exposure,
motif_node,
motif_path
node_x_brokerage(ison_networkers, "Discipline")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.