node_x_exposure() produces a motif matrix of nodes' exposure to
infection/adoption by time step.
node_x_exposure(.data)A network object of class mnet, igraph, tbl_graph, network, or similar.
For more information on the standard coercion possible,
see manynet::as_tidygraph().
A node_motif matrix with one row for each node in the network and
a column for each motif type,
giving the count of each motif in which each node participates.
It is printed as a tibble, however, to avoid greedy printing.
If the network is labelled,
then the node names will be in a column named names.
Other diffusion:
mark_diff,
measure_diffusion_infection,
measure_diffusion_net,
measure_diffusion_node,
member_diffusion,
motif_hazard
Other motifs:
motif_brokerage_net,
motif_brokerage_node,
motif_hazard,
motif_hierarchy,
motif_net,
motif_node,
motif_path,
motif_periods
Other nodal:
mark_core,
mark_degree,
mark_diff,
mark_nodes,
mark_select_node,
measure_assort_node,
measure_broker_node,
measure_brokerage,
measure_central_between,
measure_central_close,
measure_central_degree,
measure_central_eigen,
measure_closure_node,
measure_core,
measure_diffusion_node,
measure_diverse_node,
member_brokerage,
member_cliques,
member_community,
member_community_hier,
member_community_non,
member_components,
member_core,
member_diffusion,
member_equivalence,
motif_brokerage_node,
motif_node,
motif_path
node_x_exposure(play_diffusion(create_tree(12)))
#> # A tibble: 12 × 4
#> t0 t1 t2 t3
#> <dbl> <dbl> <dbl> <dbl>
#> 1 0 2 2 2
#> 2 1 1 3 3
#> 3 1 1 3 3
#> 4 0 1 1 3
#> 5 0 1 1 3
#> 6 0 1 1 2
#> # ℹ 6 more rows