| motif_path | R Documentation |
These functions include ways to take a census of the positions of nodes in a network:
node_x_tie() returns a census of the ties in a network.
For directed networks, out-ties and in-ties are bound together.
For multiplex networks, the various types of ties are bound together.
node_x_path() returns the shortest path lengths
of each node to every other node in the network.
node_x_tie(.data)
node_x_path(.data)
.data |
A network object of class |
A node_motif matrix with one row for each node in the network and
a column for each motif type,
giving the count of each motif in which each node participates.
It is printed as a tibble, however, to avoid greedy printing.
If the network is labelled,
then the node names will be in a column named names.
Dijkstra, Edsger W. 1959. "A note on two problems in connexion with graphs". Numerische Mathematik 1, 269-71. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/BF01386390")}.
Opsahl, Tore, Filip Agneessens, and John Skvoretz. 2010. "Node centrality in weighted networks: Generalizing degree and shortest paths". Social Networks 32(3): 245-51. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.socnet.2010.03.006")}.
Other motifs:
motif_brokerage_net,
motif_brokerage_node,
motif_exposure,
motif_hazard,
motif_hierarchy,
motif_net,
motif_node,
motif_periods
Other nodal:
mark_core,
mark_degree,
mark_diff,
mark_nodes,
mark_select_node,
measure_assort_node,
measure_broker_node,
measure_brokerage,
measure_central_between,
measure_central_close,
measure_central_degree,
measure_central_eigen,
measure_closure_node,
measure_core,
measure_diffusion_node,
measure_diverse_node,
member_brokerage,
member_cliques,
member_community,
member_community_hier,
member_community_non,
member_components,
member_core,
member_diffusion,
member_equivalence,
motif_brokerage_node,
motif_exposure,
motif_node
task_eg <- to_named(to_uniplex(ison_algebra, "tasks"))
(tie_cen <- node_x_tie(task_eg))
node_x_path(ison_adolescents)
node_x_path(ison_southern_women)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.