These functions measure certain topological features of networks:
net_x_change() measures the Hamming distance between two or more networks.
net_x_stability() measures the Jaccard index of stability between two or more networks.
net_x_correlation() measures the product-moment correlation between two networks.
These net_*() functions return a numeric vector the length of the number
of networks minus one. E.g., the periods between waves.
net_x_change(.data, object2)
net_x_stability(.data, object2)
net_x_correlation(.data, object2)A network object of class mnet, igraph, tbl_graph, network, or similar.
For more information on the standard coercion possible,
see manynet::as_tidygraph().
A network object.
A network_motif named numeric vector or sometimes a data frame with
one row and a column for each motif type,
giving the count of each motif in the network.
This is printed as a tibble to avoid greedy printing of long vectors.
Other change:
measure_periods
Other motifs:
motif_brokerage_net,
motif_brokerage_node,
motif_exposure,
motif_hazard,
motif_hierarchy,
motif_net,
motif_node,
motif_path